@@ -16,6 +16,7 @@ from typing import (
     cast,
     FrozenSet,
     NoReturn,
+    Tuple,
     Union,
 )
 
@@ -67,6 +68,17 @@ class ImportGraph:
             self._inner.graph.chain_exists(importer.module, imported.module, as_packages),  # type: ignore[misc]
         )
 
+    def find_shortest_chain(
+        self,
+        importer: FullPathModule,
+        imported: FullPathModule,
+    ) -> Tuple[FullPathModule, ...]:
+        raw = cast(
+            Tuple[str],
+            self._inner.graph.find_shortest_chain(importer.module, imported.module),  # type: ignore[misc]
+        )
+        return tuple(FullPathModule.assert_module(r) for r in raw)
+
     def find_children(
         self, module: FullPathModule
     ) -> FrozenSet[FullPathModule]:
