@@ -2,8 +2,12 @@ from .arch import (
     forbidden_allowlist,
     project_dag,
 )
+from arch_lint import (
+    FullPathModule,
+)
 from arch_lint.dag.check import (
-    check_dag,
+    check_dag_map,
+    dag_map_completeness,
 )
 from arch_lint.forbidden import (
     check_forbidden,
@@ -15,15 +19,21 @@ from arch_lint.private import (
     check_private,
 )
 
+root = FullPathModule.assert_module("arch_lint")
+
 
 def test_dag_creation() -> None:
     project_dag()
 
 
+def test_dag_completeness() -> None:
+    graph = ImportGraph.from_modules(root, True)
+    dag_map_completeness(project_dag(), graph, root)
+
+
 def test_dag() -> None:
-    root = "arch_lint"
-    graph = ImportGraph.build_graph(root, True)
-    check_dag(project_dag(), graph, graph.root)
+    graph = ImportGraph.from_modules(root, True)
+    check_dag_map(project_dag(), graph)
 
 
 def test_forbidden_creation() -> None:
@@ -31,13 +41,11 @@ def test_forbidden_creation() -> None:
 
 
 def test_forbidden() -> None:
-    root = "arch_lint"
-    graph = ImportGraph.build_graph(root, True)
+    graph = ImportGraph.from_modules(root, True)
     allowlist_map = forbidden_allowlist()
     check_forbidden(allowlist_map, graph)
 
 
 def test_private() -> None:
-    root = "arch_lint"
-    graph = ImportGraph.build_graph(root, False)
-    check_private(graph, graph.root)
+    graph = ImportGraph.from_modules(root, False)
+    check_private(graph, root)
